@@ -177,9 +177,14 @@ class TesserocrDetections(Detections):
 		self.level = level
 	
 	def text(self):
-		if self.level is not None:
-			return self.api.GetUTF8Text(self.level).strip("\n")
-		return self.api.GetUTF8Text().strip("\n")
+		try:
+			if self.level is not None:
+				return self.api.GetUTF8Text(self.level).strip("\n")
+			return self.api.GetUTF8Text().strip("\n")
+		except RuntimeError:
+			# For some some stupid reason tesserocr raises a RuntimeError instead of returning
+			# an empty string when there is no text on the page at all
+			return ""
 	
 	def blocks(self):
 		iterator = self.api.GetIterator()
